@@ -19,32 +19,7 @@
  *	o  return more to R and get rid of "-1" for end coding
  */
 
-#include <R.h>
-/* for R_alloc, sorting, ... */
-
-
-/* ------ EXPORTS ---------*/
-double margin(double x[], int n1, int n2);
-void R_margin(double *x, int *n1, int *n2, double *result);
-
-int score(double x[], double x_srt[], int indres[], int ind_srt[], int n);
-void R_score(double *x, int *indres, int *n, double *result);
-
-double get_new_gene(double x[], double y[], int indres[], int cluster_size,
-		    int n, int n1, int n2, int p, int used[],
-		    double x_srt[], int ind_srt[],
-		    int gen_ids[], double cluster_mittel[],
-		    double score_v[], double margin_v[],
-		    int verbose);
-
-void R_multicluster(double *y, int *resp,
-		    int *n, int *n1, int *n2,
-		    int *p, int *used,
-		    double *cluster_mean, int *startsize,
-		    int *genes_in_cluster,
-		    int *scores, double *margins,
-		    int *once_per_clust, int *c_verbose);
-/* ------ ------- ---------*/
+#include "supclust.h"
 
 
 static double maximum(double *x, int n)
